"use strict";

require("core-js/modules/es.weak-map.js");
Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = FileList;
require("core-js/modules/es.promise.js");
require("core-js/modules/web.dom-collections.iterator.js");
var _react = _interopRequireWildcard(require("react"));
var _agGridReact = require("ag-grid-react");
require("ag-grid-community/styles/ag-grid.css");
require("ag-grid-community/styles/ag-theme-alpine.css");
require("./FileList.css");
function _getRequireWildcardCache(e) { if ("function" != typeof WeakMap) return null; var r = new WeakMap(), t = new WeakMap(); return (_getRequireWildcardCache = function _getRequireWildcardCache(e) { return e ? t : r; })(e); }
function _interopRequireWildcard(e, r) { if (!r && e && e.__esModule) return e; if (null === e || "object" != typeof e && "function" != typeof e) return { default: e }; var t = _getRequireWildcardCache(r); if (t && t.has(e)) return t.get(e); var n = { __proto__: null }, a = Object.defineProperty && Object.getOwnPropertyDescriptor; for (var u in e) if ("default" !== u && {}.hasOwnProperty.call(e, u)) { var i = a ? Object.getOwnPropertyDescriptor(e, u) : null; i && (i.get || i.set) ? Object.defineProperty(n, u, i) : n[u] = e[u]; } return n.default = e, t && t.set(e, n), n; }
// Import CSS file for styling

function FileList() {
  const [gridApi, setGridApi] = (0, _react.useState)(null);
  const [gridColumnApi, setGridColumnApi] = (0, _react.useState)(null);
  const [rowData, setRowData] = (0, _react.useState)([]);
  const [loading, setLoading] = (0, _react.useState)(true);
  const [error, setError] = (0, _react.useState)(null);
  (0, _react.useEffect)(() => {
    async function fetchData() {
      try {
        const response = await fetch('http://localhost:7071/api/TestApi');
        if (!response.ok) {
          throw new Error("HTTP error: ".concat(response.status, " ").concat(response.statusText));
        }
        const result = await response.json();
        setRowData(result);
        setLoading(false);
      } catch (err) {
        setError("There was a problem fetching data: ".concat(err.message));
        setLoading(false);
      }
    }
    fetchData();
  }, []);
  const defaultColDef = {
    sortable: true,
    filter: true,
    floatingFilter: true,
    // Enable floating filter
    checkboxSelection: true // Enable row selection checkboxes
  };
  const columnDefs = [{
    headerName: 'Action',
    field: 'action',
    width: 100,
    cellRendererFramework: params => /*#__PURE__*/_react.default.createElement("input", {
      type: "checkbox",
      onClick: e => e.stopPropagation()
    })
  }, {
    headerName: 'Original Filename',
    field: 'OriginalFilename',
    cellRenderer: 'linkRenderer'
  }, {
    headerName: 'Created',
    field: 'AccountRouteId'
  }, {
    headerName: 'Uploaded',
    field: 'OwnerId'
  }, {
    headerName: 'By',
    field: 'OwnerId'
  }, {
    headerName: 'Visibility',
    field: 'OwnerId'
  }, {
    headerName: 'Type',
    field: 'OwnerId'
  }, {
    headerName: 'Size',
    field: 'OwnerId'
  }, {
    headerName: 'Job',
    field: 'OwnerId'
  }, {
    headerName: 'Signatory',
    field: 'OwnerId'
  }, {
    headerName: 'OpenSpace',
    field: 'OwnerId'
  }, {
    headerName: 'Download',
    cellRendererFramework: params => /*#__PURE__*/_react.default.createElement("button", {
      onClick: () => handleDownload(params.data.DownloadUrl)
    }, "Download")
  }];

  // Remove checkboxes from all columns except the "Action" column
  columnDefs.forEach(column => {
    if (column.field !== 'action') {
      column.checkboxSelection = false;
    }
  });
  const handleDownload = fileUrl => {
    window.open(fileUrl, '_blank');
  };
  const LinkRenderer = props => {
    return /*#__PURE__*/_react.default.createElement("a", {
      href: props.value,
      target: "_blank",
      rel: "noopener noreferrer",
      className: "blue-link" // Apply blue link style
    }, props.value);
  };
  return /*#__PURE__*/_react.default.createElement("div", null, /*#__PURE__*/_react.default.createElement("div", {
    className: "dropdowns"
  }, /*#__PURE__*/_react.default.createElement("select", {
    className: "dropdown blue"
  }, /*#__PURE__*/_react.default.createElement("option", {
    value: "upload"
  }, "Upload Files")), /*#__PURE__*/_react.default.createElement("select", {
    className: "dropdown blue"
  }, /*#__PURE__*/_react.default.createElement("option", {
    value: "request"
  }, "Request Files")), /*#__PURE__*/_react.default.createElement("select", {
    className: "dropdown blue"
  }, /*#__PURE__*/_react.default.createElement("option", {
    value: "more"
  }, "More Actions"))), /*#__PURE__*/_react.default.createElement("div", {
    className: "ag-theme-alpine",
    style: {
      height: '500px',
      width: '100%'
    }
  }, /*#__PURE__*/_react.default.createElement(_agGridReact.AgGridReact, {
    rowData: rowData,
    defaultColDef: defaultColDef,
    columnDefs: columnDefs,
    onGridReady: params => {
      setGridApi(params.api);
      setGridColumnApi(params.columnApi);
    }
  })));
}