import React, { useState, useEffect } from 'react';
import { AgGridReact } from 'ag-grid-react';
import 'ag-grid-community/styles/ag-grid.css';
import 'ag-grid-community/styles/ag-theme-alpine.css';
import './FileList.css'; // Import CSS file for styling

export default function FileList() {
    const [gridApi, setGridApi] = useState(null);
    const [gridColumnApi, setGridColumnApi] = useState(null);
    const [rowData, setRowData] = useState([]);
    const [loading, setLoading] = useState(true);
    const [error, setError] = useState(null);

    useEffect(() => {
        async function fetchData() {
            try {
                const response = await fetch('http://localhost:7071/api/TestApi');

                if (!response.ok) {
                    throw new Error(`HTTP error: ${response.status} ${response.statusText}`);
                }

                const result = await response.json();
                setRowData(result);
                setLoading(false);
            } catch (err) {
                setError(`There was a problem fetching data: ${err.message}`);
                setLoading(false);
            }
        }

        fetchData();
    }, []);

    const defaultColDef = {
        sortable: true,
        filter: true,
        floatingFilter: true, // Enable floating filter
        checkboxSelection: true, // Enable row selection checkboxes
    };

    const columnDefs = [
        {
            headerName: 'Action',
            field: 'action',
            width: 100,
            cellRendererFramework: (params) => (
                <input type="checkbox" onClick={(e) => e.stopPropagation()} />
            ),
        },
        { 
            headerName: 'Original Filename',
            field: 'OriginalFilename',
            cellRenderer: 'linkRenderer'
        },
        { headerName: 'Created', field: 'AccountRouteId' },
        { headerName: 'Uploaded', field: 'OwnerId' },
        { headerName: 'By', field: 'OwnerId' },
        { headerName: 'Visibility', field: 'OwnerId' },
        { headerName: 'Type', field: 'OwnerId' },
        { headerName: 'Size', field: 'OwnerId' },
        { headerName: 'Job', field: 'OwnerId' },
        { headerName: 'Signatory', field: 'OwnerId' },
        { headerName: 'OpenSpace', field: 'OwnerId' },
        {
            headerName: 'Download',
            cellRendererFramework: (params) => (
                <button onClick={() => handleDownload(params.data.DownloadUrl)}>Download</button>
            ),
        },
    ];
    
    // Remove checkboxes from all columns except the "Action" column
    columnDefs.forEach((column) => {
        if (column.field !== 'action') {
            column.checkboxSelection = false;
        }
    });

    const handleDownload = (fileUrl) => {
        window.open(fileUrl, '_blank');
    };

    const LinkRenderer = (props) => {
        return (
            <a
                href={props.value}
                target="_blank"
                rel="noopener noreferrer"
                className="blue-link" // Apply blue link style
            >
                {props.value}
            </a>
        );
    };

    return (
        <div>
            <div className="dropdowns">
                <select className="dropdown blue">
                    <option value="upload">Upload Files</option>
                    {/* Add other options as needed */}
                </select>
                <select className="dropdown blue">
                    <option value="request">Request Files</option>
                    {/* Add other options as needed */}
                </select>
                <select className="dropdown blue">
                    <option value="more">More Actions</option>
                    {/* Add other options as needed */}
                </select>
            </div>
            <div className="ag-theme-alpine" style={{ height: '500px', width: '100%' }}>
                <AgGridReact
                    rowData={rowData}
                    defaultColDef={defaultColDef}
                    columnDefs={columnDefs}
                    onGridReady={(params) => {
                        setGridApi(params.api);
                        setGridColumnApi(params.columnApi);
                    }}
                ></AgGridReact>
            </div>
        </div>
    );
}
